@@ -5,8 +5,16 @@ in because a new donation has ocurred.
 """
 
 
-def writeIPC(folder, value):
-    """Write to the IPC file."""
+def writeIPC(folder: str, value: str):
+    """Write to the IPC file.
+
+    This is used to let the call_tracker module know that a new\
+    donation has been made.
+
+    :param folder: The location of trackerIPC.txt
+    :param value: The value to write to the file.
+    :raises: IOError
+    """
     folders = folder
     try:
         with open(f'{folders}/trackerIPC.txt', 'w') as file:
